@@ -5,20 +5,31 @@
 #'  to build the tree 
 #' 
 #' 
-#' @param x an object of class \code{party}
+#' @param x an object of class \code{party} or \code{PlackettLuce}
+#' @param log logical, if \code{TRUE} log-worth coefficients are 
+#'  displayed instead of worth
+#' @param ref optional, character or integer for the reference item when
+#'  \var{log} = \code{TRUE}
+#' @param ... additional arguments passed to methods. See details
+#' @details 
+#' multcomp = TRUE adds multi-comparison letters from multcompView
+#' ci.level = numeric for the confidence interval levels
 #' @return a vector with the node labels, 
-#'  a data.frame with node rules, a ggplot
+#'  a data.frame with node rules, a ggplot object
 #' @author Kauê de Sousa
 #' @examples 
 #' \donttest{
 #' library("PlackettLuce")
+#' library("ggplot2")
+#' 
 #' data("beans", package = "PlackettLuce")
+#' 
 #' G = rank_tricot(data = beans,
-#'                  items = c(1:3),
-#'                  input = c(4:5),
-#'                  group = TRUE,
-#'                  additional.rank = beans[c(6:8)])
-#'  
+#'                 items = c(1:3),
+#'                 input = c(4:5),
+#'                 group = TRUE,
+#'                 additional.rank = beans[c(6:8)])
+#'   
 #' pld = cbind(G, beans[,c("maxTN", "season", "lon")])
 #'
 #' tree = pltree(G ~ maxTN + season + lon, data = pld)
@@ -31,198 +42,26 @@
 #' 
 #' plot(tree)
 #' 
-#' plot(tree, log = TRUE)
+#' plot(tree, log = FALSE)
+#' 
+#' #################################
+#' 
+#' # Plot PlackettLuce 
+#' R = matrix(c(1, 2, 4, 3,
+#'              4, 1, 2, 3,
+#'              2, 4, 1, 3,
+#'              1, 2, 3, 0,
+#'              2, 1, 4, 3,
+#'              1, 4, 3, 2), nrow = 6, byrow = TRUE)
+#' colnames(R) = c("apple", "banana", "orange", "pear")
+#' R = as.rankings(R)
+#' 
+#' mod = PlackettLuce(R)
+#' 
+#' plot(mod)
+#' 
 #' }
-#' @importFrom stats model.frame reorder
-#' @importFrom partykit nodeids data_party node_party breaks_split partynode
-#'  kids_node id_node split_node varid_split index_split right_split
-#' @export
-node_labels = function(x) {
-  
-  rules = .list.rules.party(x)
-  rules = paste(rules, collapse = "  ")
-  
-  var = names(model.frame(x))
-  
-  labels = sapply(var, function(x) {
-    grepl(x, rules)
-  })
-  
-  names(labels[labels == TRUE])
-  
-}
-
-#' Get node rules 
-#' @rdname node_labels
-#' @export
-node_rules = function(x){
-  
-  node_ids = partykit::nodeids(x, terminal = TRUE)
-  
-  result = data.frame()
-  
-  for (i in seq_along(node_ids)) {
-    r = data.frame(node = node_ids[i],
-                    rules = .list.rules.party(x, node_ids[i]))
-    
-    result = rbind(result, r)
-    
-  }
-  
-  rule = result$rules
-  rule = gsub("%in%","@", rule)
-  rule = gsub("[(]|[)]| c","", rule)
-  rule = gsub("  "," ", rule)
-  rule = gsub('"NA",',"", rule)
-  rule = gsub(', "NA"',"", rule)
-  rule = gsub(",", "COMMA", rule)
-  rule = gsub("[.]", "DOT", rule)
-  rule = gsub("@", "EQUAL", rule)
-  rule = gsub("&", " AND ", rule)
-  rule = gsub("<=", " LOWEQUAL ", rule)
-  rule = gsub("=>", " HIGHEQUAL ", rule)
-  rule = gsub("<", " LOW ", rule)
-  rule = gsub(">", " HIGH ", rule)
-  
-  # remove all other special characters
-  rule = gsub("[[:punct:]]", "", rule)
-  
-  # reposition the key special characters
-  rule = gsub("  ", " ", rule)
-  rule = gsub("LOWEQUAL", "<=", rule)
-  rule = gsub("HIGHEQUAL", "=>", rule)
-  rule = gsub("LOW", "<", rule)
-  rule = gsub("HIGH", ">", rule)
-  rule = gsub("EQUAL", "= ", rule)
-  rule = gsub("AND", "&", rule)
-  rule = gsub("COMMA", ",", rule)
-  rule = gsub("DOT", ".", rule)
-  rule = gsub(", NA", "", rule)
-  rule = gsub("NA,", "", rule)
-  
-  result$rules = rule
-  
-  return(result)
-  
-}
-
-#' Get the top items out of a decision tree
-#' @param top an integer for the number of items to return
-#' @rdname node_labels
-#' @export 
-top_items = function(x, top = 5) {
-  
-  if (length(x) > 1) {
-    
-    coef_x = coef(x, log = FALSE)
-    
-    bestitems = apply(coef_x, 1 , function(y) {
-      names(rev(sort(y)))[1:top]
-    })
-    
-    bestitems = as.data.frame(bestitems)
-    
-    names(bestitems) = paste0("Node", 
-                               nodeids(x, terminal = TRUE))
-    
-    return(bestitems)
-    
-  }
-  
-  if (length(x) == 1){
-    
-    coef_x = coef(x, log = FALSE)
-    
-    bestitems = names(rev(sort(coef_x)))[1:top]
-    
-    return(bestitems)
-    
-  }
-  
-}
-
-#' Imported from partykit
-#' @param i node ids
-#' @noRd
-.list.rules.party = function (x, i = NULL, ...) 
-{
-  if (is.null(i)) 
-    i = partykit::nodeids(x, terminal = TRUE)
-  if (length(i) > 1) {
-    ret = sapply(i, .list.rules.party, x = x)
-    names(ret) = if (is.character(i)) 
-      i
-    else names(x)[i]
-    return(ret)
-  }
-  if (is.character(i) && !is.null(names(x))) 
-    i = which(names(x) %in% i)
-  stopifnot(length(i) == 1 & is.numeric(i))
-  stopifnot(i <= length(x) & i >= 1)
-  i = as.integer(i)
-  dat = partykit::data_party(x, i)
-  if (!is.null(x$fitted)) {
-    findx = which("(fitted)" == names(dat))[1]
-    fit = dat[, findx:ncol(dat), drop = FALSE]
-    dat = dat[, -(findx:ncol(dat)), drop = FALSE]
-    if (ncol(dat) == 0) 
-      dat = x$data
-  }
-  else {
-    fit = NULL
-    dat = x$data
-  }
-  rule = c()
-  recFun = function(node) {
-    if (partykit::id_node(node) == i) 
-      return(NULL)
-    kid = sapply(partykit::kids_node(node), partykit::id_node)
-    whichkid = max(which(kid <= i))
-    split = partykit::split_node(node)
-    ivar = partykit::varid_split(split)
-    svar = names(dat)[ivar]
-    index = partykit::index_split(split)
-    if (is.factor(dat[, svar])) {
-      if (is.null(index)) 
-        index = ((1:nlevels(dat[, svar])) > partykit::breaks_split(split)) + 
-          1
-      slevels = levels(dat[, svar])[index == whichkid]
-      srule = paste(svar, " %in% c(\"", paste(slevels, 
-                                               collapse = "\", \"", sep = ""), "\")", sep = "")
-    }
-    else {
-      if (is.null(index)) 
-        index = 1:length(kid)
-      breaks = cbind(c(-Inf, partykit::breaks_split(split)), 
-                      c(partykit::breaks_split(split), Inf))
-      sbreak = breaks[index == whichkid, ]
-      right = partykit::right_split(split)
-      srule = c()
-      if (is.finite(sbreak[1])) 
-        srule = c(srule, paste(svar, ifelse(right, ">", 
-                                             ">="), sbreak[1]))
-      if (is.finite(sbreak[2])) 
-        srule = c(srule, paste(svar, ifelse(right, "<=", 
-                                             "<"), sbreak[2]))
-      srule = paste(srule, collapse = " & ")
-    }
-    rule <<- c(rule, srule)
-    return(recFun(node[[whichkid]]))
-  }
-  node = recFun(partykit::node_party(x))
-  paste(rule, collapse = " & ")
-}
-
-
-#' Plot PlackettLuce tree
-#' @param log logical, if \code{TRUE} log-worth coefficients are 
-#'  displayed instead of worth
-#' @param ref optional, character for the reference item when
-#'  \var{log} = \code{TRUE}
-#' @param ci.level an integer for the confidence interval levels
-#' @param ... additional arguments passed to methods. See details
-#' @details 
-#' Argument multcomp = TRUE adds multi-comparison letters from multcompView
+#' 
 #' @importFrom stats update
 #' @importFrom PlackettLuce freq
 #' @importFrom partykit nodeids
@@ -238,9 +77,9 @@ top_items = function(x, top = 5) {
 #' @method plot pltree
 #' @export
 plot.pltree = function(x, 
-                        log = TRUE, 
-                        ref = NULL, 
-                        ci.level = 0.95, ...){
+                       log = TRUE, 
+                       ref = NULL,
+                       ...){
   
   
   if (length(x) == 1) {
@@ -265,7 +104,6 @@ plot.pltree = function(x,
   # make panels
   p = try(build_tree_nodes(nodes, 
                        log = log,
-                       ci.level = ci.level,
                        ref = ref,
                        node.ids = node_id,
                        n.obs = nobs, 
@@ -286,6 +124,20 @@ plot.pltree = function(x,
   
 }
 
+#' @import methods
+#' @rdname node_labels
+#' @method plot PlackettLuce
+#' @export
+plot.PlackettLuce = function(x,  
+                             ...){
+  
+  build_tree_nodes(list(x), ...) +
+    ggplot2::theme(strip.background = ggplot2::element_blank(),
+                   strip.text.x = ggplot2::element_blank())
+    
+    
+}
+
 #' Build tree
 #' This function builds the party tree
 #' @param x a party object
@@ -308,10 +160,10 @@ build_tree_branches = function(x, ...){
                                          digits = 1))),
       ggplot2::aes(label = ""),
       ggplot2::aes(label = id)),
-      line_gpar = list(list(size = 12),
-                       list(size = 10),
-                       list(size = 10),
-                       list(size = 10,
+      line_gpar = list(list(linewidth = 12),
+                       list(linewidth = 10),
+                       list(linewidth = 10),
+                       list(linewidth = 10,
                             col = "black",
                             fontface = "bold",
                             alignment = "center")
@@ -327,6 +179,7 @@ build_tree_branches = function(x, ...){
 #' @param node.ids a vector of integers with node ids
 #' @param n.obs a vector of integers with N per node
 #' @param multcomp TRUE adds multi-comparison groups
+#' @param levels optional, a vector with the order of labels in axis Y
 #' @inheritParams plot.pltree
 #' @noRd
 build_tree_nodes = function(x, 
@@ -336,6 +189,7 @@ build_tree_nodes = function(x,
                             node.ids = NULL,
                             n.obs = NULL,
                             multcomp = FALSE, 
+                            levels = NULL,
                             ...){
   
   if (isFALSE(log)) ref = NULL
@@ -427,7 +281,14 @@ build_tree_nodes = function(x,
   coeffs$node = factor(paste0("Node ", coeffs$node, " (n=", coeffs$nobs, ")"),
                         levels = node_lev)
   
-  coeffs$items = factor(coeffs$items, levels = rev(sort(items)))
+  
+  if (is.null(levels)) {
+    
+    levels = rev(sort(items))
+    
+  }
+  
+  coeffs$items = factor(coeffs$items, levels = levels)
   
   # Get max and min values for the x axis in the plot
   xmax = round(max(coeffs$bmax, na.rm = TRUE) + 0.01, digits = 4)
@@ -490,31 +351,202 @@ build_tree_nodes = function(x,
   
 }
 
-# coeffs = data.frame(estimate = c(-0.6, 0, 0.4, 0.2, -0.1, 0.4),
-#                      items = rep(c("banana", "apple", "orange"), 2),
-#                      groups = "",
-#                      node = rep(c(1,2), each = 3))
-# 
-# coeffs
-# 
-# xinter = 0
-# bmin = 0
-# bmax = 0
-# xbreaks = c(-0.78, 0, 0.89)
-# xlabs = xbreaks
-# xmin = -0.78
-# xmin = xmin + (xmin * 0.15)
-# xmax = 0.89
-# xmax = xmax + (xmax * 0.15)
+
+
+#' @importFrom stats model.frame reorder
+#' @importFrom partykit nodeids data_party node_party breaks_split partynode
+#'  kids_node id_node split_node varid_split index_split right_split
+#' @rdname node_labels
+#' @export
+node_labels = function(x) {
+  
+  rules = .list.rules.party(x)
+  rules = paste(rules, collapse = "  ")
+  
+  var = names(model.frame(x))
+  
+  labels = sapply(var, function(x) {
+    grepl(x, rules)
+  })
+  
+  names(labels[labels == TRUE])
+  
+}
+
+#' Get node rules 
+#' @rdname node_labels
+#' @importFrom partykit nodeids
+#' @export
+node_rules = function(x){
+  
+  node_ids = partykit::nodeids(x, terminal = TRUE)
+  
+  result = data.frame()
+  
+  for (i in seq_along(node_ids)) {
+    r = data.frame(node = node_ids[i],
+                   rules = .list.rules.party(x, node_ids[i]))
+    
+    result = rbind(result, r)
+    
+  }
+  
+  rule = result$rules
+  rule = gsub("%in%","@", rule)
+  rule = gsub("[(]|[)]| c","", rule)
+  rule = gsub("  "," ", rule)
+  rule = gsub('"NA",',"", rule)
+  rule = gsub(', "NA"',"", rule)
+  rule = gsub(",", "COMMA", rule)
+  rule = gsub("[.]", "DOT", rule)
+  rule = gsub("@", "EQUAL", rule)
+  rule = gsub("&", " AND ", rule)
+  rule = gsub("<=", " LOWEQUAL ", rule)
+  rule = gsub("=>", " HIGHEQUAL ", rule)
+  rule = gsub("<", " LOW ", rule)
+  rule = gsub(">", " HIGH ", rule)
+  
+  # remove all other special characters
+  rule = gsub("[[:punct:]]", "", rule)
+  
+  # reposition the key special characters
+  rule = gsub("  ", " ", rule)
+  rule = gsub("LOWEQUAL", "<=", rule)
+  rule = gsub("HIGHEQUAL", "=>", rule)
+  rule = gsub("LOW", "<", rule)
+  rule = gsub("HIGH", ">", rule)
+  rule = gsub("EQUAL", "= ", rule)
+  rule = gsub("AND", "&", rule)
+  rule = gsub("COMMA", ",", rule)
+  rule = gsub("DOT", ".", rule)
+  rule = gsub(", NA", "", rule)
+  rule = gsub("NA,", "", rule)
+  
+  result$rules = rule
+  
+  return(result)
+  
+}
+
+#' Get the top items out of a decision tree
+#' @param top an integer for the number of items to return
+#' @rdname node_labels
+#' @export 
+top_items = function(x, top = 5) {
+  
+  if (length(x) > 1) {
+    
+    coef_x = coef(x, log = FALSE)
+    
+    bestitems = apply(coef_x, 1 , function(y) {
+      names(rev(sort(y)))[1:top]
+    })
+    
+    bestitems = as.data.frame(bestitems)
+    
+    names(bestitems) = paste0("Node", 
+                              nodeids(x, terminal = TRUE))
+    
+    return(bestitems)
+    
+  }
+  
+  if (length(x) == 1){
+    
+    coef_x = coef(x, log = FALSE)
+    
+    bestitems = names(rev(sort(coef_x)))[1:top]
+    
+    return(bestitems)
+    
+  }
+  
+}
+
+#' Imported from partykit
+#' @param i node ids
+#' @noRd
+.list.rules.party = function (x, i = NULL, ...) 
+{
+  if (is.null(i)) 
+    i = partykit::nodeids(x, terminal = TRUE)
+  if (length(i) > 1) {
+    ret = sapply(i, .list.rules.party, x = x)
+    names(ret) = if (is.character(i)) 
+      i
+    else names(x)[i]
+    return(ret)
+  }
+  if (is.character(i) && !is.null(names(x))) 
+    i = which(names(x) %in% i)
+  stopifnot(length(i) == 1 & is.numeric(i))
+  stopifnot(i <= length(x) & i >= 1)
+  i = as.integer(i)
+  dat = partykit::data_party(x, i)
+  if (!is.null(x$fitted)) {
+    findx = which("(fitted)" == names(dat))[1]
+    fit = dat[, findx:ncol(dat), drop = FALSE]
+    dat = dat[, -(findx:ncol(dat)), drop = FALSE]
+    if (ncol(dat) == 0) 
+      dat = x$data
+  }
+  else {
+    fit = NULL
+    dat = x$data
+  }
+  rule = c()
+  recFun = function(node) {
+    if (partykit::id_node(node) == i) 
+      return(NULL)
+    kid = sapply(partykit::kids_node(node), partykit::id_node)
+    whichkid = max(which(kid <= i))
+    split = partykit::split_node(node)
+    ivar = partykit::varid_split(split)
+    svar = names(dat)[ivar]
+    index = partykit::index_split(split)
+    if (is.factor(dat[, svar])) {
+      if (is.null(index)) 
+        index = ((1:nlevels(dat[, svar])) > partykit::breaks_split(split)) + 
+          1
+      slevels = levels(dat[, svar])[index == whichkid]
+      srule = paste(svar, " %in% c(\"", paste(slevels, 
+                                              collapse = "\", \"", sep = ""), "\")", sep = "")
+    }
+    else {
+      if (is.null(index)) 
+        index = 1:length(kid)
+      breaks = cbind(c(-Inf, partykit::breaks_split(split)), 
+                     c(partykit::breaks_split(split), Inf))
+      sbreak = breaks[index == whichkid, ]
+      right = partykit::right_split(split)
+      srule = c()
+      if (is.finite(sbreak[1])) 
+        srule = c(srule, paste(svar, ifelse(right, ">", 
+                                            ">="), sbreak[1]))
+      if (is.finite(sbreak[2])) 
+        srule = c(srule, paste(svar, ifelse(right, "<=", 
+                                            "<"), sbreak[2]))
+      srule = paste(srule, collapse = " & ")
+    }
+    rule <<- c(rule, srule)
+    return(recFun(node[[whichkid]]))
+  }
+  node = recFun(partykit::node_party(x))
+  paste(rule, collapse = " & ")
+}
 
 
 #' @rdname multcompPL
 #' @noRd
-multcompPL = function(mod, items = NULL, threshold = 0.05, adjust = "none", ...){
-  
+multcompPL = function(mod,
+                      items = NULL,
+                      threshold = 0.05,
+                      adjust = "none",
+                      ...){
+
   #get estimates with quasi-SEs
   qv1 = qvcalc::qvcalc(mod, ...)$qvframe
-  
+
   #reduce frame to only selected items if not all comparisons are desired
   if (!is.null(items)) {
     qv1 = subset(qv1, rownames(qv1) %in% items)
@@ -523,11 +555,11 @@ multcompPL = function(mod, items = NULL, threshold = 0.05, adjust = "none", ...)
       stop("Less than 2 items selected")
     }
   }
-  
+
   #set up matrices for all differences and pooled errors
   diffs = mat.or.vec(nrow(qv1),nrow(qv1))
   ses = mat.or.vec(nrow(qv1),nrow(qv1))
-  
+
   for(i in 1:nrow(qv1)){
     for(j in 1:nrow(qv1)){
       #get differences and pooled ses
@@ -535,45 +567,45 @@ multcompPL = function(mod, items = NULL, threshold = 0.05, adjust = "none", ...)
       ses[i,j] = sqrt(qv1$quasiVar[i] + qv1$quasiVar[j])
     }
   }
-  
+
   #calculate z scores
   z = diffs/ses
   #TO DO: What DF to use to use here? Is it just the resid DF?
   p = 2 * (1 - stats::pt(abs(z), mod$df.residual))
-  
+
   #adjust p-value if you want to adjust. make sure to only take each p once for adjustment
   p[upper.tri(p)] = stats::p.adjust(p[upper.tri(p)], method = adjust)
-  
+
   #make sure lower triangular is mirror of upper
   p[lower.tri(p)] = t(p)[lower.tri(p)]
-  
+
   #set rownames
   rownames(p) = colnames(p) = rownames(qv1)
-  
+
   #re-order qv output to ensure letters are produced in a sensible order
   qv1$items = stats::reorder(factor(rownames(qv1)), qv1$estimate, mean)
   qv1 = qv1[order(qv1$estimate, decreasing = TRUE), ]
-  
+
   #get mean seperation letter groupings
-  args = list(formula = estimate ~ items, 
-               x = p, 
+  args = list(formula = estimate ~ items,
+               x = p,
                data = qv1,
                compare = "<",
                threshold =  threshold,
                Letters = letters,
                reversed = FALSE)
-  
+
   let = do.call("multcompLetters2", args)
-  
+
   qv1$group = let$Letters
-  
+
   qv1 = qv1[, union("items", names(qv1))]
-  
+
   row.names(qv1) = seq_along(qv1$group)
-  
+
   class(qv1) = union("multcompPL", class(qv1))
-  
+
   return(qv1)
-  
+
 }
 
